… | OiRA

Help

1. Undirbúningur
3. Greining + Mat
   1. 1 Commercial manned guarding
   2. Ω Aðrar áhættur á vinnustaðnum (ef við á)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Ekki opnað
   - Frestað
   - Áhættan er ekki til staðar
   - Áhættan er til staðar
4. Aðgerðaáætlun
5. Skýrsla
6. Staða 0%

## Lýstu áhættunni…

Ekki er þörf á fleiri úrbótaaðgerðum

Select the priority of this risk Low Medium High
Upplýsingar
Hlaðið inn myndlabel_upload_image
Athugasemdir

Scroll to top
Back

## add-risk.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More